@@ -1,17 +1,5 @@
-/* Copyright 2017-2018 ccls Authors
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-  http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-==============================================================================*/
+// Copyright 2017-2018 ccls Authors
+// SPDX-License-Identifier: Apache-2.0
 
 #include "fuzzy_match.hh"
 #include "include_complete.hh"
@@ -504,11 +492,11 @@ void MessageHandler::textDocument_completion(CompletionParam &param,
   if (param.position.line >= 0 && param.position.line < wf->buffer_lines.size())
     buffer_line = wf->buffer_lines[param.position.line];
 
-  clang::CodeCompleteOptions cCOpts;
-  cCOpts.IncludeBriefComments = true;
-  cCOpts.IncludeCodePatterns = StringRef(buffer_line).ltrim().startswith("#");
-  cCOpts.IncludeFixIts = true;
-  cCOpts.IncludeMacros = true;
+  clang::CodeCompleteOptions ccOpts;
+  ccOpts.IncludeBriefComments = true;
+  ccOpts.IncludeCodePatterns = StringRef(buffer_line).ltrim().startswith("#");
+  ccOpts.IncludeFixIts = true;
+  ccOpts.IncludeMacros = true;
 
   if (param.context.triggerKind == CompletionTriggerKind::TriggerCharacter &&
       param.context.triggerCharacter) {
@@ -518,7 +506,7 @@ void MessageHandler::textDocument_completion(CompletionParam &param,
     case '"':
     case '/':
     case '<':
-      ok = cCOpts.IncludeCodePatterns; // start with #
+      ok = ccOpts.IncludeCodePatterns; // start with #
       break;
     case ':':
       ok = col >= 0 && buffer_line[col] == ':'; // ::
@@ -584,13 +572,13 @@ void MessageHandler::textDocument_completion(CompletionParam &param,
       };
 
   if (cache.isCacheValid(path, begin_pos)) {
-    CompletionConsumer consumer(cCOpts, true);
+    CompletionConsumer consumer(ccOpts, true);
     cache.withLock([&]() { consumer.ls_items = cache.result; });
     callback(&consumer);
   } else {
     manager->comp_tasks.pushBack(std::make_unique<SemaManager::CompTask>(
         reply.id, param.textDocument.uri.getPath(), begin_pos,
-        std::make_unique<CompletionConsumer>(cCOpts, false), cCOpts, callback));
+        std::make_unique<CompletionConsumer>(ccOpts, false), ccOpts, callback));
   }
 }
 } // namespace ccls
