@@ -222,7 +222,7 @@ readCompilerArgumentsFromFile(const std::string &path) {
     return {};
   std::vector<const char *> args;
   for (line_iterator i(*mbOrErr.get(), true, '#'), e; i != e; ++i) {
-    std::string line = *i;
+    std::string line(*i);
     doPathMapping(line);
     args.push_back(intern(line));
   }
@@ -632,7 +632,7 @@ void Project::index(WorkingFiles *wfiles, RequestId id) {
 void Project::indexRelated(const std::string &path) {
   auto &gi = g_config->index;
   GroupMatch match(gi.whitelist, gi.blacklist);
-  std::string stem = sys::path::stem(path);
+  StringRef stem = sys::path::stem(path);
   std::vector<const char *> args, extra_args;
   for (const std::string &arg : g_config->clang.extraArgs)
     extra_args.push_back(intern(arg));
